<?php
namespace Elementor;

class EMAF_Widget extends Widget_Base {
    
    public function get_name() {
        return 'emaf-forms';
    }
    
    public function get_title() {
        return esc_html__('Envato Market Affiliate Forms', 'emaf');
    }
    
    public function get_icon() {
        return 'eicon-form-horizontal';
    }
    
    public function get_categories() {
        return [ 'modeltheme-affiliate-widgets' ];
    }
    
    protected function register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'General Options', 'emaf' ),
            ]
        );
        
        $this->add_control(
            'action_url',
            [
                'label' => esc_html__( 'Form Action URL', 'emaf' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'themeforest.net',
                'options' => [
                    'themeforest.net'  => esc_html__( 'Themeforest', 'emaf' ),
                    'codecanyon.net' => esc_html__( 'Codecanyon', 'emaf' ),
                ],
            ]
        );
        $this->add_control(
            'tf_categories',
            [
                'label' => esc_html__( 'ThemeForest Categories', 'emaf' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '/category/site-templates'     => esc_html__('Site Templates', 'emaf'),
                    '/category/wordpress'     => esc_html__('WordPress', 'emaf'),
                    '/category/cms-themes'     => esc_html__('CMS Themes', 'emaf'),
                    '/category/ecommerce'  => esc_html__('eCommerce', 'emaf'),
                    '/category/blogging'    => esc_html__('Blogging', 'emaf'),
                    '/category/marketing' => esc_html__('Marketing', 'emaf'),
                    '/category/forums'   => esc_html__('Forums', 'emaf'),
                    '/category/muse-templates'    => esc_html__('Muse Templates', 'emaf'),
                    '/category/jamstack'   => esc_html__('Jamstack', 'emaf'),
                    '/category/courses'      => esc_html__('Courses', 'emaf'),
                    '/category/template-kits'    => esc_html__('Template Kits', 'emaf'),
                    '/category/ui-templates'      => esc_html__('UI Templates', 'emaf'),
                ],
                'condition' => [
                    'action_url' => 'themeforest.net',
                ],
            ]
        );

        $this->add_control(
            'cc_categories',
            [
                'label' => esc_html__( 'CodeCanyon Categories', 'emaf' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '/category/javascript'     => esc_html__('JavaScript', 'emaf'),
                    '/category/php-scripts'     => esc_html__('PHP Scripts', 'emaf'),
                    '/category/net'     => esc_html__('.NET', 'emaf'),
                    '/category/wordpress'  => esc_html__('WordPress', 'emaf'),
                    '/category/plugins'    => esc_html__('Plugins', 'emaf'),
                    '/category/css' => esc_html__('CSS', 'emaf'),
                    '/category/html5'   => esc_html__('HTML5', 'emaf'),
                    '/category/mobile'    => esc_html__('Mobile', 'emaf'),
                    '/category/apps'   => esc_html__('Apps', 'emaf'),
                    '/category/skins'      => esc_html__('Skins', 'emaf'),
                    '/category/edge-animate-templates'    => esc_html__('Edge Animate Templates', 'emaf'),
                ],
                'condition' => [
                    'action_url' => 'codecanyon.net',
                ],
            ]
        );

        $this->add_control(
            'placeholder',
            [
                'label' => esc_html__('Submit Placeholder', 'emaf'),
                'type' => Controls_Manager::TEXT,
                'default' => 'e. g. responsive WordPress',
            ]
        );
        $this->add_control(
            'submit_button_label',
            [
                'label' => esc_html__( 'Submit Label', 'emaf' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter Submit button label', 'emaf' ),
                'default' => 'Search',
            ]
        );
        $this->add_control(
            'color',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Submit Background Color', 'emaf' ),
                'default' => '#6CA12B',
            ]
        );
        $this->add_control(
            'btn_color',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Submit Text Color', 'emaf' ),
                'default' => '#FFF',
            ]
        );
        $this->add_control(
            'impact_aff_id',
            [
                'label' => esc_html__( 'Impact.com Affiliate ID', 'emaf' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Eg: 1285662', 'emaf' ),
                'default' => '1285662',
            ]
        );
        $this->end_controls_section();

    }
    
    protected function render() {
        $settings                   = $this->get_settings_for_display();
        $action_url                 = $settings['action_url'];
        $impact_aff_id              = $settings['impact_aff_id'];
        $submit_button_label        = $settings['submit_button_label'];
        $color                      = $settings['color'];
        $placeholder                = $settings['placeholder'];
        $btn_color                  = $settings['btn_color'];
        $tf_categories              = $settings['tf_categories'];
        $cc_categories              = $settings['cc_categories'];

        $shortcode_content = '';
        $shortcode_content .= do_shortcode('[emaf-builder-shortcode impact_aff_id="'.esc_attr($impact_aff_id).'" action_url="'.esc_attr($action_url).'" color="'.esc_attr($color).'" placeholder="'.esc_attr($placeholder).'" btn_color="'.esc_attr($btn_color).'"  submit_button_label="'.esc_attr($submit_button_label).'" tf_categories="'.esc_attr($tf_categories).'" cc_categories="'.esc_attr($cc_categories).'" ]');

        echo  $shortcode_content;
    }
    
    protected function content_template() {

    }
}